Do you speak London?
====================

Command line tool for naturla language identification, also known as langID. Currently supporting 4 languages only, English, French, Spanish and Portuguese.

$ python dysl.py WRITE SOME TEXT HERE TO BE CLASSIFIED

Contacts
--------
 
+ Name: [Tarek Amr](http://tarekamr.appspot.com/)
+ Twitter: [@gr33ndata](https://twitter.com/gr33ndata)
